@@ -22,18 +22,23 @@ import inspect
 import argparse
 import collections
 
-VERSION = (1,2,1)
+VERSION = (1,2,2)
 
 from . import tools
-from . import keywords
-from . import debug
-from . import tasks
-from . import backward
-
 from argpext.tools import ChDir
+
+from . import keywords
 from argpext.keywords import KeyWords
+
+from . import debug
 from argpext.debug import FrameRef,chainref,DebugPrint
+
+from . import prints
+
+from . import tasks
 from argpext.tasks import display,make_hook,Task,Node,Main
+
+from . import backward
 from argpext.backward import Function,Unit,Categorical
 
 
@@ -58,3 +63,11 @@ __all__ = [
     'Function','Unit','Categorical'
     ]
 
+from . import rst
+
+
+class Main(Node):
+    SUBS = [('tasks', tasks.Main),
+            ('rst', rst.Main)
+            ]
+
